/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

/*
 * Here is a simple example of retrieving data with carob.
 * A controller must be running on the local host. This example reads data from
 * the base created with sequoia's demo/demo-raidb1.sh script.
 * Compilation: use makefile or:
 * g++ -I../../include -L../.. -lcarob read_example.cpp -o read_example
 */

#include "ResultSetMetaData.hpp"
#include "DriverResultSet.hpp"
#include "Statement.hpp"
#include "Connection.hpp"
#include "Common.hpp"
#include <iostream>
#include <vector>
#ifdef __MINGW32__
  //#pragma comment(lib, "ws2_32.lib")
  #include <winsock2.h>
#endif

using namespace CarobNS;
using std::wcout;
using std::endl;

int main(int argc, char *argv[])
{
#ifdef __MINGW32__
  //init windows socket lib
  WSADATA WSAData;
  if (isInfoEnabled())
    logInfo(L"read_example", L"Initializing windows socket library");
  if (WSAStartup(MAKEWORD(2,0), &WSAData) != 0)
  {
    if (isErrorEnabled())
      logError(L"read_example", L"Unable to find suitable windows socket library");
    throw ConnectionException(L"Unable to find suitable windows socket library");
    return false;
  }
#endif
  setLogLevel(LOG_LEVEL_DEBUG);
  
  // 1- Connecting:
  // 1.1 Create the parameters of the connection
  std::vector<ControllerInfo> ctrls;
  ctrls.push_back(ControllerInfo(L"192.168.0.39", 25322));
  
  ConnectionParameters connectionPrms(ctrls,
                                      L"myDB",
                                      L"user",
                                      L"");
  try
  {
    // 1.3 3rd step: connect to controller
    Connection connection(connectionPrms);

    // Now, we are connected to the controller

    // 2- Executing the request
    // 2.1 The easier way to create a request is to use a statement
    Statement* statementPtr = connection.createStatement();
    // statementPtr->setFetchSize(1);
    // 2.2 Execute the request and get a pointer to the result
    DriverResultSet* drsPtr = statementPtr->executeQuery(
        L"SELECT * FROM address");
    // 3- Getting the results of the request
    // 3.1 Let's display 50 rows using metadata and toString() method
    ResultSetMetaData rsmd(drsPtr);
    // 3.2 Iterate through the rows
    for (int i=0; i<50; i++)
    {
      // 3.3 Retrieve the next row
      drsPtr->next();
      // 3.4 Iterate through the columns      
      for (int j=0; j<rsmd.getColumnCount(); j++)
        wcout<<drsPtr->getAsString(j+1)<<L"\t";
      wcout<<endl;
    }
    // 4- Clean-up: the statement will be automatically deleted by the
    // connection that created it. If you want to free the memory anyway, use
    // the function from connection:
    connection.deleteStatement(statementPtr);
  }
  // 5- Deal with errors
  catch (CarobException ce)
  {
    wcout<<L"Error occured: "<<ce.description()<<endl;
  }
  // we could detail:
  // catch (AuthenticationException ae)
  // catch (BackendException be)
  // catch (SocketIOException sioe)
  // etc.
  catch (...) //always a good idea
  {
    wcout<<L"An unknow error occured"<<endl;
  }
#ifdef __MINGW32__
  WSACleanup();
#endif
}
