/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */
#ifndef SYSTEMDEPENDANTDEFS_HPP_
#define SYSTEMDEPENDANTDEFS_HPP_

//TODO: Add #ifdefs for each supported archi

namespace
{

////////////////////////////////////////////////////////////////////////////////
// Sockets options
/**
 * Communication domain for socket creation. This selects the protocol family
 * which will be used for communications. Defined in <sys/socket.h> or
 * "man 2 socket" for more info
 */
const int SOCKET_CREATION_DOMAIN          = PF_INET;
// const int SOCKET_CREATION_DOMAIN          = PF_INET6;  //for IPv6

/**
 * In Carob, we want to recover from closed socket errors. So we will tell the
 * system *not* to send sigpipes when writing on a closed socket.
 * Solutions to this are system dependant:
 * -> *nixes have MSG_NOSIGNAL flag for send() function
 * -> MaxOS/X >= 10.1 and FreeBSD have no MSG_NOSIGNAL but a socket option SO_NOSIGPIPE
 * -> ...
 */


/** Write options. Flag given for each send() on the socket */
const int SOCKET_SEND_FLAGS               = 0
#if !defined SO_NOSIGPIPE && !defined __MINGW32__ //*nix
|MSG_NOSIGNAL
#endif
;

}; //anonymous namespace
#endif /*SYSTEMDEPENDANTDEFS_HPP_*/
