/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#include <iostream>

#include "TestBeginCommitRollback.hpp"

#include "Statement.hpp"
#include "DriverResultSet.hpp"

#include "Common.hpp"

using std::wstring;

using namespace CarobNS;

void TestBeginCommitRollback::setUp()
{
  ConnectionSetup::setUp();
  connectionPtr->setAutoCommit(false);
}

void TestBeginCommitRollback::testReadRequestAndCommit()
{
  wstring fctName(L"TestBeginCommitRollback::testReadRequestAndCommit");
  Statement* stPtr = connectionPtr->createStatement();
  stPtr->executeQuery(L"select * from address");
  connectionPtr->commit();
  if (isInfoEnabled())
  {
    logInfo(fctName, L"Read and commit succeeded");
  }
}

void TestBeginCommitRollback::testReadRequestAndRollback()
{
  wstring fctName(L"TestBeginCommitRollback::testReadRequestAndRollback");
  Statement* stPtr = connectionPtr->createStatement();
  stPtr->executeQuery(L"select * from address");
  connectionPtr->rollback();
  if (isInfoEnabled())
  {
    logInfo(fctName, L"Read and rollback succeeded");
  }
}

void TestBeginCommitRollback::testWriteRequestAndCommit()
{
  wstring fctName(L"TestBeginCommitRollback::testWriteRequestAndCommit");
  Statement* stPtr = connectionPtr->createStatement();
  stPtr->executeUpdate(L"update product set name='commited' where id=0");
  connectionPtr->commit();
  DriverResultSet* drsPtr = stPtr->executeQuery(L"select * from product where id=0");
  drsPtr->next();
  // check written data
  wstring strRead = drsPtr->getString(2);
  CPPUNIT_ASSERT(strRead == L"commited");
  if (isInfoEnabled())
  {
    logInfo(fctName, L"Write and commit succeeded");
  }
}

void TestBeginCommitRollback::testWriteRequestAndRollback()
{
  wstring fctName(L"TestBeginCommitRollback::testWriteRequestAndRollback");
  Statement* stPtr = connectionPtr->createStatement();
  stPtr->executeUpdate(L"update product set name='rollbacked' where id=0");
  connectionPtr->rollback();
  DriverResultSet* drsPtr = stPtr->executeQuery(L"select * from product where id=0");
  drsPtr->next();
  // check written data
  wstring strRead = drsPtr->getString(2);
  CPPUNIT_ASSERT(strRead != L"rollbacked");
  if (isInfoEnabled())
  {
    logInfo(fctName, L"Write and rollback succeeded");
  }
}

CppUnit::Test* TestBeginCommitRollback::suite()
{
  CppUnit::TestSuite *suiteOfTests = new CppUnit::TestSuite( "TestExecReadRequest" );
  suiteOfTests->addTest(new CppUnit::TestCaller<TestBeginCommitRollback>(
                                 "TestBeginCommitRollback::testReadRequestAndCommit", 
                                 &TestBeginCommitRollback::testReadRequestAndCommit));
  suiteOfTests->addTest(new CppUnit::TestCaller<TestBeginCommitRollback>(
                                 "TestBeginCommitRollback::testReadRequestAndRollback", 
                                 &TestBeginCommitRollback::testReadRequestAndRollback));
  suiteOfTests->addTest(new CppUnit::TestCaller<TestBeginCommitRollback>(
                                 "TestBeginCommitRollback::testWriteRequestAndCommit", 
                                 &TestBeginCommitRollback::testWriteRequestAndCommit));
  suiteOfTests->addTest(new CppUnit::TestCaller<TestBeginCommitRollback>(
                                 "TestBeginCommitRollback::testWriteRequestAndRollback", 
                                 &TestBeginCommitRollback::testWriteRequestAndRollback));

  return suiteOfTests;
}
