/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTEXECWRITEREQUEST_H_
#define TESTEXECWRITEREQUEST_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for ExecWriteRequest command.
 * Tries to run a dummy request, then a request on a dummy table, then a 
 * correct request and finally a correct request played 1000 times
 * A controller *MUST* run locally for test success !!!
 */
class TestExecWriteRequest : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /**
   * Tries to send a dummy write request to the controller and checks that the
   * error is consistent.
   */
  void testWriteBadRequest();
  /**
   * Tries to do a good write request on a dummy table and checks that the
   * error is consistent.
   */
  void testWriteBadTable();
  /**
   * Sends a valid update request to the controller and checks that there is no
   * error.
   */
  void testWriteGood();
  /**
   * Sends 1000 valid update requests to the controller and checks that there is
   * no error.
   * DISABLED TEST because too long
   */
  void testWriteThousandGood();
};

#endif /*TESTEXECWRITEREQUEST_H_*/
