/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTEXECREADREQUEST_H_
#define TESTEXECREADREQUEST_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for ExecReadRequest command.
 * Tries to run a dummy request, then a request on a dummy table, then a 
 * correct request and displays the 50 first rows.
 * A controller *MUST* run locally for test success !!!
 */
class TestExecReadRequest : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /**
   * Tries to send a dummy read request to the controller and checks that the
   * error is consistent.
   */
  void testReadBadRequest();
  /**
   * Tries to do a good read request on a dummy table and checks that the
   * error is consistent.
   */
  void testReadBadTable();
  /**
   * Sends a valid select request to the controller and checks that there is no
   * error. Also displays a part of the result for manual check.
   */
  void testReadGood();
  /**
   * Tests a read with max rows to 1 and checks that the second call to next()
   * returns false
   */
  void testReadWithMaxRows();
};

#endif /*TESTEXECREADREQUEST_H_*/
