/**
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Marc Herbert
 * Contributor(s): 
 */

#include "Common.hpp"
#include "CarobException.hpp"
#include "DriverResultSet.hpp"
#include "Statement.hpp"


#include "TestSimpleUnicode.hpp"

#define TABLE_NAME L"unicodebasic"

#define DEFAULT_SQL_STRING_TYPE L"VARCHAR(200)"
#define TABLE_TYPE "(teststring " DEFAULT_SQL_STRING_TYPE L")"


using namespace CarobNS;

using std::wstring;

// warning: some DBMS (e.g., PostgreSQL) support only C-style, Null Terminated Strings.
// This test WILL FAIL with them. (SQLstate 08P01 for PostgreSQL)

namespace {

    // PBK
    // phi beta kappa + zero + last character (kappa) again

    // wchar_t wide_pbk_[] = { 0x03c6, 0x03b2, 0x03ba };
    // wstring wide_pbk(wide_pbk_, 3);
    // this is is even more evil (see SEQUOIA-133)
    wchar_t wide_pbk_[] = { 0x03c6, 0x03b2, 0x03ba, 0, 0x03ba };
    wstring wide_pbk(wide_pbk_, 5);

}

void TestSimpleUnicode::testBasic()
{
    std::wstring fctName(L"TestSimpleUnicode::testBasic");

    if (isInfoEnabled())
    {
        logInfo(fctName, L"Executing replace table " TABLE_NAME L" " TABLE_TYPE);
    }

    createOrReplaceTable(connectionPtr, TABLE_NAME, TABLE_TYPE);

    Statement *stmt = connectionPtr->createStatement();
    
    wstring insertcmd(L"INSERT INTO " TABLE_NAME " values ('");
    insertcmd += wide_pbk;
    insertcmd += L"')";

    int updatecount = stmt->executeUpdate(insertcmd);
    CPPUNIT_ASSERT(1 == updatecount);

    DriverResultSet* drsPtr = stmt->executeQuery(L"SELECT * FROM " TABLE_NAME);
    CPPUNIT_ASSERT(drsPtr->next());

    wstring returned_pbk = drsPtr->getString(1);
    CPPUNIT_ASSERT(0 == wide_pbk.compare(returned_pbk));

    CPPUNIT_ASSERT(!drsPtr->next());

}

// List of tests in this class
CppUnit::Test* TestSimpleUnicode::suite()
{
    CppUnit::TestSuite *suiteOfTests = new CppUnit::TestSuite( "TestSimpleUnicode" );
    suiteOfTests->addTest(new CppUnit::TestCaller<TestSimpleUnicode>(
                              "TestSimpleUnicode::testBasic",
                              &TestSimpleUnicode::testBasic));

    return suiteOfTests;
}


/*
 * Local Variables:
 * c-file-style: "bsd"
 * c-basic-offset: 4
 * indent-tabs-mode: nil
 * End:
 */
