/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTPREPAREDSTATEMENT_H_
#define TESTPREPAREDSTATEMENT_H_

#include "../ConnectionSetup.hpp"

/**
 * Test class for prepared statement.
 * Even there is no real prepared statement class, any statement or parameter
 * statement can be prepared by the command <code>getMetaData()</code>.
 * This class tests both statement types preparation.
 * This is basically a copy of exec read and exec write commands testing
 * demo-raidb1 *MUST* run locally for test success !!!
 */
class TestPreparedStatement : public ConnectionSetup
{
public:
  /** Suite of tests to be run */
  static CppUnit::Test* suite();

  /**
   * Creates a Statement and prepares it without setting the query first (should throw an exception)
   */
  void testPrepareEmptyStatement();
  /**
   * Creates a ParameterStatement and prepares it without setting the query first (should throw an exception)
   */
  void testPrepareEmptyParameterStatement();
  /**
   * Creates a Statement, executes an update and tries to prepare it (should throw an exception)
   */
  void testPrepareUpdateStatement();
  /**
   * Creates a ParameterStatement, executes an update and tries to prepare it (should return NULL)
   */
  void testPrepareUpdateParameterStatement();
  /**
   * Creates a Statement, executes a query and tries to prepare it (should return the result's metadata)
   */
  void testPrepareExecuteQueryStatement();
  /**
   * Creates a ParameterStatement, executes a query and tries to prepare it (should return the result's metadata)
   */
  void testPrepareExecuteQueryParameterStatement();
  /**
   * Creates a Statement, executes a query with execute and tries to prepare it (should return the result's metadata)
   */
  void testPrepareExecuteStatement();
  /**
   * Creates a ParameterStatement, executes a query with execute and tries to prepare it (should return the result's metadata)
   */
  void testPrepareExecuteParameterStatement();
  /**
   * Creates a Statement, set the query and prepares it
   */
  void testPrepareStatement();
  /**
   * Creates a ParameterStatement, set the query and prepares it
   */
  void testPrepareParameterStatement();

};

#endif /*TESTPREPAREDSTATEMENT_H_*/
